==> monodevelop_4.0.12+dfsg.orig.tar.gz: monodevelop-4.0.12/external/nrefactory/ICSharpCode.NRefactory.Tests/CSharp/Refactoring/RefactoringStructureTests.cs <==
﻿// Copyright (c) 2010-2013 AlphaSierraPapa for the SharpDevelop Team
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of this
// software and associated documentation files (the "Software"), to deal in the Software
// without restriction, including without limitation the rights to use, copy, modify, merge,
// publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons
// to whom the Software is furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in all copies or
// substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
// INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE
// FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.

using System;
using System.Reflection;
using NUnit.Framework;

namespace ICSharpCode.NRefactory.CSharp.Refactoring
{
	[TestFixture]
	public class RefactoringStructureTests
	{
		[Test]
		public void GatherVisitorBaseClass()
		{
			Assembly NR_CSharp = typeof(ICodeIssueProvider).Assembly;
			bool foundGatherVisitor = false;
			foreach (var topLevelType in NR_CSharp.GetTypes()) {
				foreach (var nestedType in topLevelType.GetNestedTypes(BindingFlags.NonPublic | BindingFlags.Public)) {
					if (nestedType.Name != "GatherVisitor")
						continue;
					foundGatherVisitor = true;
					bool foundGatherVisitorBase = false;
					for (Type baseType = nestedType.BaseType; baseType != null; baseType = baseType.BaseType) {
						if (baseType.Name == "GatherVisitorBase`1") {
							foundGatherVisitorBase = true;
							Assert.AreEqual(new[] { topLevelType }, baseType.GetGenericArguments(), "Invalid base type of " + nestedType.FullName);
						}
					}
					Assert.IsTrue(foundGatherVisitorBase, nestedType.FullName + " should derive from GatherVisitorBase");
				}
			}
			Assert.IsTrue(foundGatherVisitor, "where are the gather visitors?");
		}
	}
}

==> monodevelop_4.2.2.orig.tar.gz: monodevelop-4.2.2/external/nrefactory/ICSharpCode.NRefactory.Tests/CSharp/Refactoring/RefactoringStructureTests.cs <==
﻿// Copyright (c) 2010-2013 AlphaSierraPapa for the SharpDevelop Team
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of this
// software and associated documentation files (the "Software"), to deal in the Software
// without restriction, including without limitation the rights to use, copy, modify, merge,
// publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons
// to whom the Software is furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in all copies or
// substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
// INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE
// FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.

using System;
using System.Reflection;
using NUnit.Framework;

namespace ICSharpCode.NRefactory.CSharp.Refactoring
{
	[TestFixture]
	public class RefactoringStructureTests
	{
		[Test]
		public void GatherVisitorBaseClass()
		{
			Assembly NR_CSharp = typeof(InconsistentNamingIssue).Assembly;
			bool foundGatherVisitor = false;
			foreach (var topLevelType in NR_CSharp.GetTypes()) {
				foreach (var nestedType in topLevelType.GetNestedTypes(BindingFlags.NonPublic | BindingFlags.Public)) {
					if (nestedType.Name != "GatherVisitor")
						continue;
					foundGatherVisitor = true;
					bool foundGatherVisitorBase = false;
					for (Type baseType = nestedType.BaseType; baseType != null; baseType = baseType.BaseType) {
						if (baseType.Name == "GatherVisitorBase`1") {
							foundGatherVisitorBase = true;
							Assert.AreEqual(new[] { topLevelType }, baseType.GetGenericArguments(), "Invalid base type of " + nestedType.FullName);
						}
					}
					Assert.IsTrue(foundGatherVisitorBase, nestedType.FullName + " should derive from GatherVisitorBase");
				}
			}
			Assert.IsTrue(foundGatherVisitor, "where are the gather visitors?");
		}
	}
}
